Useful Links — coala 0.11.0.rc1 documentation

# Useful Links

The purpose of this document is to gather links that coala developers usually use throughout their work.

If you ever encounter a link that helped you or that is not a part of the document and should be, feel free to suggest it by creating an issue in our issue tracker.

## Git-Links

- Git Tutorial
- coala’s Git Tutorial
- Commit message guidelines
- coala Commits
- How to rebase
- Rebase Concept
- Short Rebase Tutorial
- coala Git Repository

## Python-Links

- Code Style
- coala Code Style
- Python Tutorial
- Shorter Tutorial Version

## rST-Links

- Basic rST
- Syntax

## coala-Links

- coala Shortlinks
- Install coala
- coala Issues
- coala Tutorial
- coala Chat
- coala Newcomers’ Guide
- coala Review Process